/*------------------------------------------------------------------------------
-- This file is a part of the QLop Software
-- Copyright (C) 2015, Plasma Physics Laboratory - CNRS
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-------------------------------------------------------------------------------*/
/*-- Author : Alexis Jeandet
-- Mail : alexis.jeandet@member.fsf.org
----------------------------------------------------------------------------*/
#ifndef CASSINITOOLS_H
#define CASSINITOOLS_H

#include <QObject>
#include <QWidget>
#include <qlopservice.h>
#include <cassinitoolsgui.h>
#include <cassinidatafile.h>
#include <qlopdata.h>
#include <SocExplorerPlot.h>
#include <cassinitoolssettingsgui.h>

class CassiniTools: public QLopService
{
    Q_OBJECT
private:
    static CassiniTools* _self;
    static QDockWidget* m_gui;
    static CassiniToolsGUI* m_CassiniToolsGUI;
    static CassiniToolsSettingsGUI* m_SettingsGui;
    static CassiniDataFile* m_dataFile;
    static int m_defaultPlot,m_fftPlot;
    static SocExplorerPlotActions* ExportAction;
    CassiniTools(bool noGUI=false, QObject *parent=0);
    ~CassiniTools();
    static void makePlot();
public:
    static void init(bool noGUI=false,QObject *parent = 0);
    static CassiniTools *self();
    static void decodeFGMData(const QString& file);
    // QLopService methodes
    QDockWidget* getGUI();
    const QString& serviceName();
    static void plotFile(const QString &File);
public slots:
    void plot_TAB_File(const QString& fileName);
    void export_view(int PID);
    void export_view_Predefined_FileName(int PID);
    void compute_fft_on_view(int PID);
private slots:
    static QString generateFileName(const QString& baseName,const QString& extension);
    void dataReady(QLopDataList data);
    void fileWritten();
};

#endif // CASSINITOOLS_H

